@@ -1,6 +1,6 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
 /*
- * Copyright (C) 2011, 2013 Red Hat, Inc.
+ * Copyright © 2011 – 2017 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -17,8 +17,11 @@
  */
 
 #include "config.h"
+
+#include <gio/gio.h>
 #include <glib/gi18n-lib.h>
 
+#include "goaenums.h"
 #include "goaerror.h"
 
 /**
