@@ -1,6 +1,6 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
 /*
- * Copyright (C) 2012, 2013, 2014, 2015 Red Hat, Inc.
+ * Copyright © 2012 – 2017 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -59,6 +59,22 @@ goa_http_client_new (void)
 
 /* ---------------------------------------------------------------------------------------------------- */
 
+static void
+http_client_log_printer (SoupLogger         *logger,
+                         SoupLoggerLogLevel  level,
+                         gchar               direction,
+                         const gchar        *data,
+                         gpointer            user_data)
+{
+  gchar *message;
+
+  message = g_strdup_printf ("%c %s", direction, data);
+  g_log_default_handler ("goa", G_LOG_LEVEL_DEBUG, message, NULL);
+  g_free (message);
+}
+
+/* ---------------------------------------------------------------------------------------------------- */
+
 typedef struct
 {
   GCancellable *cancellable;
@@ -191,20 +207,6 @@ http_client_check_response_cb (SoupSession *session, SoupMessage *msg, gpointer
   g_source_unref (source);
 }
 
-static void
-http_client_log_printer (SoupLogger         *logger,
-                         SoupLoggerLogLevel  level,
-                         gchar               direction,
-                         const gchar        *data,
-                         gpointer            user_data)
-{
-  gchar *message;
-
-  message = g_strdup_printf ("%c %s", direction, data);
-  g_log_default_handler ("goa", G_LOG_LEVEL_DEBUG, message, NULL);
-  g_free (message);
-}
-
 void
 goa_http_client_check (GoaHttpClient       *self,
                        const gchar         *uri,
@@ -236,9 +238,7 @@ goa_http_client_check (GoaHttpClient       *self,
   g_object_unref (logger);
 
   data->accept_ssl_errors = accept_ssl_errors;
-
   data->msg = soup_message_new (SOUP_METHOD_GET, uri);
-  soup_message_headers_append (data->msg->request_headers, "Connection", "close");
 
   if (cancellable != NULL)
     {
@@ -269,6 +269,7 @@ goa_http_client_check_finish (GoaHttpClient *self, GAsyncResult *res, GError **e
 {
   GSimpleAsyncResult *simple;
 
+  g_return_val_if_fail (GOA_IS_HTTP_CLIENT (self), FALSE);
   g_return_val_if_fail (g_simple_async_result_is_valid (res, G_OBJECT (self), goa_http_client_check), FALSE);
   g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
@@ -310,6 +311,13 @@ goa_http_client_check_sync (GoaHttpClient       *self,
   CheckSyncData data;
   GMainContext *context = NULL;
 
+  g_return_val_if_fail (GOA_IS_HTTP_CLIENT (self), FALSE);
+  g_return_val_if_fail (uri != NULL && uri[0] != '\0', FALSE);
+  g_return_val_if_fail (username != NULL && username[0] != '\0', FALSE);
+  g_return_val_if_fail (password != NULL && password[0] != '\0', FALSE);
+  g_return_val_if_fail (cancellable == NULL || G_IS_CANCELLABLE (cancellable), FALSE);
+  g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
+
   data.error = error;
 
   context = g_main_context_new ();
