@@ -1,6 +1,6 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
 /*
- * Copyright (C) 2011, 2013, 2015 Red Hat, Inc.
+ * Copyright © 2011 – 2017 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -24,7 +24,6 @@
 #include <stdlib.h>
 
 #include "goaimapauthlogin.h"
-#include "goaprovider.h"
 #include "goautils.h"
 
 /*
@@ -506,7 +505,7 @@ goa_imap_auth_login_run_sync (GoaMailAuth         *auth,
 
   if (!self->greeting_absent)
     {
-      response = g_data_input_stream_read_line (input, NULL, cancellable, error);
+      response = goa_utils_data_input_stream_read_line (input, NULL, cancellable, error);
       if (response == NULL)
         goto out;
       g_debug ("< %s", response);
@@ -527,7 +526,7 @@ goa_imap_auth_login_run_sync (GoaMailAuth         *auth,
 
   /* Check if LOGIN is supported or not */
 
-  response = g_data_input_stream_read_line (input, NULL, cancellable, error);
+  response = goa_utils_data_input_stream_read_line (input, NULL, cancellable, error);
   if (response == NULL)
     goto out;
   g_debug ("< %s", response);
@@ -535,7 +534,7 @@ goa_imap_auth_login_run_sync (GoaMailAuth         *auth,
     goto out;
   g_clear_pointer (&response, g_free);
 
-  response = g_data_input_stream_read_line (input, NULL, cancellable, error);
+  response = goa_utils_data_input_stream_read_line (input, NULL, cancellable, error);
   if (response == NULL)
     goto out;
   g_debug ("< %s", response);
@@ -552,7 +551,7 @@ goa_imap_auth_login_run_sync (GoaMailAuth         *auth,
   g_clear_pointer (&request, g_free);
 
   /* Skip post-login CAPABILITY, if any */
-  response = g_data_input_stream_read_line (input, NULL, cancellable, error);
+  response = goa_utils_data_input_stream_read_line (input, NULL, cancellable, error);
   if (response == NULL)
     goto out;
   g_debug ("< %s", response);
@@ -560,7 +559,7 @@ goa_imap_auth_login_run_sync (GoaMailAuth         *auth,
     goto check_login_response;
   g_clear_pointer (&response, g_free);
 
-  response = g_data_input_stream_read_line (input, NULL, cancellable, error);
+  response = goa_utils_data_input_stream_read_line (input, NULL, cancellable, error);
   if (response == NULL)
     goto out;
   g_debug ("< %s", response);
@@ -604,7 +603,7 @@ goa_imap_auth_login_starttls_sync (GoaMailAuth         *auth,
 
   /* Check the greeting */
 
-  response = g_data_input_stream_read_line (input, NULL, cancellable, error);
+  response = goa_utils_data_input_stream_read_line (input, NULL, cancellable, error);
   if (response == NULL)
     goto out;
   g_debug ("< %s", response);
@@ -624,7 +623,7 @@ goa_imap_auth_login_starttls_sync (GoaMailAuth         *auth,
 
   /* Check if STARTTLS is supported or not */
 
-  response = g_data_input_stream_read_line (input, NULL, cancellable, error);
+  response = goa_utils_data_input_stream_read_line (input, NULL, cancellable, error);
   if (response == NULL)
     goto out;
   g_debug ("< %s", response);
@@ -632,7 +631,7 @@ goa_imap_auth_login_starttls_sync (GoaMailAuth         *auth,
     goto out;
   g_clear_pointer (&response, g_free);
 
-  response = g_data_input_stream_read_line (input, NULL, cancellable, error);
+  response = goa_utils_data_input_stream_read_line (input, NULL, cancellable, error);
   if (response == NULL)
     goto out;
   g_debug ("< %s", response);
@@ -648,7 +647,7 @@ goa_imap_auth_login_starttls_sync (GoaMailAuth         *auth,
     goto out;
   g_clear_pointer (&request, g_free);
 
-  response = g_data_input_stream_read_line (input, NULL, cancellable, error);
+  response = goa_utils_data_input_stream_read_line (input, NULL, cancellable, error);
   if (response == NULL)
     goto out;
   g_debug ("< %s", response);
