@@ -1,6 +1,6 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
 /*
- * Copyright (C) 2012-2015 Red Hat, Inc.
+ * Copyright © 2012 – 2017 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -33,6 +33,9 @@ void             goa_object_skeleton_attach_calendar       (GoaObjectSkeleton *o
                                                             gboolean           calendar_enabled,
                                                             gboolean           accept_ssl_errors);
 
+void             goa_object_skeleton_attach_chat           (GoaObjectSkeleton *object,
+                                                            gboolean           chat_enabled);
+
 void             goa_object_skeleton_attach_contacts       (GoaObjectSkeleton *object,
                                                             const gchar       *uri,
                                                             gboolean           contacts_enabled,
@@ -46,6 +49,18 @@ void             goa_object_skeleton_attach_files          (GoaObjectSkeleton *o
                                                             gboolean           files_enabled,
                                                             gboolean           accept_ssl_errors);
 
+void             goa_object_skeleton_attach_maps           (GoaObjectSkeleton *object,
+                                                            gboolean           maps_enabled);
+
+void             goa_object_skeleton_attach_photos         (GoaObjectSkeleton *object,
+                                                            gboolean           photos_enabled);
+
+void             goa_object_skeleton_attach_printers       (GoaObjectSkeleton *object,
+                                                            gboolean           printers_enabled);
+
+void             goa_object_skeleton_attach_read_later     (GoaObjectSkeleton *object,
+                                                            gboolean           read_later_enabled);
+
 G_END_DECLS
 
 #endif /* __GOA_OBJECT_SKELETON_UTILS_H__ */
