@@ -1,6 +1,6 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
 /*
- * Copyright (C) 2011, 2013, 2014, 2015 Red Hat, Inc.
+ * Copyright © 2011 – 2017 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -23,7 +23,6 @@
 #include <glib/gi18n-lib.h>
 
 #include "goasmtpauth.h"
-#include "goaprovider.h"
 #include "goautils.h"
 
 /*
@@ -220,11 +219,12 @@ smtp_auth_get_domain (GoaSmtpAuth   *self,
                       GError       **error)
 {
   GoaMail *mail;
-  const gchar *email_address;
   gchar *domain;
+  gchar *email_address;
 
   mail = NULL;
   domain = NULL;
+  email_address = NULL;
 
   if (self->domain != NULL)
     {
@@ -242,7 +242,7 @@ smtp_auth_get_domain (GoaSmtpAuth   *self,
           goto out;
         }
 
-      email_address = goa_mail_get_email_address (mail);
+      email_address = goa_mail_dup_email_address (mail);
       if (!goa_utils_parse_email_address (email_address, NULL, &domain))
         {
           g_set_error (error,
@@ -263,6 +263,7 @@ smtp_auth_get_domain (GoaSmtpAuth   *self,
 
  out:
   g_clear_object (&mail);
+  g_free (email_address);
   return domain;
 }
 
