@@ -1,6 +1,6 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
 /*
- * Copyright (C) 2011, 2013, 2014, 2015 Red Hat, Inc.
+ * Copyright © 2011 – 2017 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -27,9 +27,8 @@
 #include <glib.h>
 #include <glib-object.h>
 
-#include <goabackend/goabackendtypes.h>
-
 #include "goamailauth.h"
+#include "goaprovider.h"
 
 G_BEGIN_DECLS
 
